using System;
using System.Data;
using System.IO;
using parseEPG;

/// History:
/// 
/// Initial Release: 05.10.2004
/// 
///	09.10.2004	-	added can read the original epg.data File; was not Unix-Textfile aware before
///				-	fixed crashed when no Event Title
///	
namespace VDRGUI
{
	/// <summary>
	/// liest Daten aus epg.data Datei
	/// </summary>
	public class parseEPG
	{
		/// <summary>
		/// Pfad und Dateiname der epg.data Datei
		/// </summary>
		private static string pv_s_epgdata_filename;
		private static EPGData geparsteDaten = new EPGData();


		public parseEPG(string s_epg_data_filename)
		{
			pv_s_epgdata_filename = s_epg_data_filename;
		}

		/// <summary>
		/// parst das EPG und erzeugt die entsprechenden Datenstrukturen im Speicher
		/// liefert Statuscode zurck:
		///	0 = kein Fehler
		///	1 = epg.data nicht gefunden
		/// </summary>
		public int parse_EPG()
		{			
			#region Parser
			if (!File.Exists(pv_s_epgdata_filename))
			{ 
				return 1; 
			}    
	
			using (TextReader epgStreamReader = File.OpenText(pv_s_epgdata_filename)) 
			{
				EPGData.channelRow aktuellerSender = null;
				EPGData.epgDataRow aktuellerEvent = null;

				while (epgStreamReader.Peek() >= 0) 
				{
					string temporary = null;
					string[] t_gesplittet;

					temporary = epgStreamReader.ReadLine();

					#region parsen
					switch(temporary[0])
					{
						case 'C':
							aktuellerSender = geparsteDaten.channel.NewchannelRow();
							temporary = temporary.Remove(0,2);
							t_gesplittet = temporary.Split(' ');
							aktuellerSender.channel_string = t_gesplittet[0];
							aktuellerSender.channel_name = t_gesplittet[1];
							geparsteDaten.channel.AddchannelRow(aktuellerSender);
							break;
						case 'c':
							//geparsteDaten.channel.AddchannelRow(aktuellerSender);
							break;
						case 'E':
							temporary = temporary.Remove(0,2);
							aktuellerEvent = geparsteDaten.epgData.NewepgDataRow();
							aktuellerEvent.channel_string = aktuellerSender.channel_string;
							aktuellerEvent.event_string = temporary;
							t_gesplittet = temporary.Split(' ');
							aktuellerEvent.event_start = Convert.ToInt64(t_gesplittet[1]);
							aktuellerEvent.event_duration = Convert.ToInt64(t_gesplittet[2]);
							aktuellerEvent.event_title = "n/a";
							break;
						case 'T':
							temporary = temporary.Remove(0,2);
							aktuellerEvent.event_title = temporary;
							break;
						case 'D':
							temporary = temporary.Remove(0,2);
							aktuellerEvent.event_long_description = temporary;
							break;
						case 'S':
							temporary = temporary.Remove(0,2);
							aktuellerEvent.event_short_description = temporary;
							break;
						case 'V':
							temporary = temporary.Remove(0,2);
							aktuellerEvent.event_vps = Convert.ToInt64(temporary,10);
							break;
						case 'e':
							geparsteDaten.epgData.AddepgDataRow(aktuellerEvent);
							break;
					}
					#endregion
				}
			}
			#endregion
			return 0;
		}

		/// <summary>
		/// erzeugt aus den geparsten EPG Daten XML Daten
		/// </summary>
		public string getXMLEPG()
		{
			return geparsteDaten.GetXml();
		}

		/// <summary>
		/// DEMO Methode die zeigt wie man auf die Daten zugreift
		/// </summary>
		public void DEMO_OutputData()
		{
			foreach (DataRow dr in geparsteDaten.channel.Rows)
			{
				Console.WriteLine(dr["channel_name"].ToString());
				foreach (DataRow dr2 in dr.GetChildRows("channelepgDataRelation"))
				{
					Console.Write("\t\t" + dr2["event_title"].ToString());
				}
			}
		}

	}
}
